import 'dart:async';

import 'enum.dart';
import 'event.dart';

abstract class MessageManagerPlatform {
  StreamController<TIMEvent> messageStreamController = StreamController.broadcast();

  Stream<TIMEvent> get messageListener {
    return messageStreamController.stream;
  }

  void init();

  Future<void> sendTextMessage({
    required String userId,
    required String text,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
  });

  Future<void> sendTextGroupMessage({
    required String groupId,
    required String text,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
  });

  Future<void> sendCustomMessage({
    required String userId,
    required List<int> data,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
    bool isExcludedFromUnreadCount = true,
  });

  Future<void> sendCustomGroupMessage({
    required String groupId,
    required List<int> data,
    TIMMessagePriority priority = TIMMessagePriority.high,
    bool isOnlineUserOnly = false,
    bool isExcludedFromUnreadCount = true,
  });

  void dispose() {
    messageStreamController.close();
  }
}
